@@ -208,7 +208,7 @@ public class FilteredPluginArtifactsSelectionDialog extends FilteredItemsSelecti
 		}
 
 		private Image getImage(String location) {
-			if (new File(location).isFile())
+			if (location != null && new File(location).isFile())
 				return JavaUI.getSharedImages().getImage(org.eclipse.jdt.ui.ISharedImages.IMG_OBJS_JAR);
 			return PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJ_FOLDER);
 		}
@@ -478,7 +478,7 @@ public class FilteredPluginArtifactsSelectionDialog extends FilteredItemsSelecti
 
 	@Override
 	protected IStatus validateItem(Object item) {
-		return new Status(IStatus.OK, "org.eclipse.pde.ui", 0, "", null); //$NON-NLS-1$ //$NON-NLS-2$
+		return Status.OK_STATUS;
 	}
 
 	@Override
